# coding=utf-8
from __future__ import unicode_literals
from collections import OrderedDict

from .. import BaseProvider

localized = True


class Provider(BaseProvider):
    all_colors = OrderedDict((
        ("AliceBlue", "#F0F8FF"),
        ("AntiqueWhite", "#FAEBD7"),
        ("Aqua", "#00FFFF"),
        ("Aquamarine", "#7FFFD4"),
        ("Azure", "#F0FFFF"),
        ("Beige", "#F5F5DC"),
        ("Bisque", "#FFE4C4"),
        ("Black", "#000000"),
        ("BlanchedAlmond", "#FFEBCD"),
        ("Blue", "#0000FF"),
        ("BlueViolet", "#8A2BE2"),
        ("Brown", "#A52A2A"),
        ("BurlyWood", "#DEB887"),
        ("CadetBlue", "#5F9EA0"),
        ("Chartreuse", "#7FFF00"),
        ("Chocolate", "#D2691E"),
        ("Coral", "#FF7F50"),
        ("CornflowerBlue", "#6495ED"),
        ("Cornsilk", "#FFF8DC"),
        ("Crimson", "#DC143C"),
        ("Cyan", "#00FFFF"),
        ("DarkBlue", "#00008B"),
        ("DarkCyan", "#008B8B"),
        ("DarkGoldenRod", "#B8860B"),
        ("DarkGray", "#A9A9A9"),
        ("DarkGreen", "#006400"),
        ("DarkKhaki", "#BDB76B"),
        ("DarkMagenta", "#8B008B"),
        ("DarkOliveGreen", "#556B2F"),
        ("DarkOrange", "#FF8C00"),
        ("DarkOrchid", "#9932CC"),
        ("DarkRed", "#8B0000"),
        ("DarkSalmon", "#E9967A"),
        ("DarkSeaGreen", "#8FBC8F"),
        ("DarkSlateBlue", "#483D8B"),
        ("DarkSlateGray", "#2F4F4F"),
        ("DarkTurquoise", "#00CED1"),
        ("DarkViolet", "#9400D3"),
        ("DeepPink", "#FF1493"),
        ("DeepSkyBlue", "#00BFFF"),
        ("DimGray", "#696969"),
        ("DodgerBlue", "#1E90FF"),
        ("FireBrick", "#B22222"),
        ("FloralWhite", "#FFFAF0"),
        ("ForestGreen", "#228B22"),
        ("Fuchsia", "#FF00FF"),
        ("Gainsboro", "#DCDCDC"),
        ("GhostWhite", "#F8F8FF"),
        ("Gold", "#FFD700"),
        ("GoldenRod", "#DAA520"),
        ("Gray", "#808080"),
        ("Green", "#008000"),
        ("GreenYellow", "#ADFF2F"),
        ("HoneyDew", "#F0FFF0"),
        ("HotPink", "#FF69B4"),
        ("IndianRed", "#CD5C5C"),
        ("Indigo", "#4B0082"),
        ("Ivory", "#FFFFF0"),
        ("Khaki", "#F0E68C"),
        ("Lavender", "#E6E6FA"),
        ("LavenderBlush", "#FFF0F5"),
        ("LawnGreen", "#7CFC00"),
        ("LemonChiffon", "#FFFACD"),
        ("LightBlue", "#ADD8E6"),
        ("LightCoral", "#F08080"),
        ("LightCyan", "#E0FFFF"),
        ("LightGoldenRodYellow", "#FAFAD2"),
        ("LightGray", "#D3D3D3"),
        ("LightGreen", "#90EE90"),
        ("LightPink", "#FFB6C1"),
        ("LightSalmon", "#FFA07A"),
        ("LightSeaGreen", "#20B2AA"),
        ("LightSkyBlue", "#87CEFA"),
        ("LightSlateGray", "#778899"),
        ("LightSteelBlue", "#B0C4DE"),
        ("LightYellow", "#FFFFE0"),
        ("Lime", "#00FF00"),
        ("LimeGreen", "#32CD32"),
        ("Linen", "#FAF0E6"),
        ("Magenta", "#FF00FF"),
        ("Maroon", "#800000"),
        ("MediumAquaMarine", "#66CDAA"),
        ("MediumBlue", "#0000CD"),
        ("MediumOrchid", "#BA55D3"),
        ("MediumPurple", "#9370DB"),
        ("MediumSeaGreen", "#3CB371"),
        ("MediumSlateBlue", "#7B68EE"),
        ("MediumSpringGreen", "#00FA9A"),
        ("MediumTurquoise", "#48D1CC"),
        ("MediumVioletRed", "#C71585"),
        ("MidnightBlue", "#191970"),
        ("MintCream", "#F5FFFA"),
        ("MistyRose", "#FFE4E1"),
        ("Moccasin", "#FFE4B5"),
        ("NavajoWhite", "#FFDEAD"),
        ("Navy", "#000080"),
        ("OldLace", "#FDF5E6"),
        ("Olive", "#808000"),
        ("OliveDrab", "#6B8E23"),
        ("Orange", "#FFA500"),
        ("OrangeRed", "#FF4500"),
        ("Orchid", "#DA70D6"),
        ("PaleGoldenRod", "#EEE8AA"),
        ("PaleGreen", "#98FB98"),
        ("PaleTurquoise", "#AFEEEE"),
        ("PaleVioletRed", "#DB7093"),
        ("PapayaWhip", "#FFEFD5"),
        ("PeachPuff", "#FFDAB9"),
        ("Peru", "#CD853F"),
        ("Pink", "#FFC0CB"),
        ("Plum", "#DDA0DD"),
        ("PowderBlue", "#B0E0E6"),
        ("Purple", "#800080"),
        ("Red", "#FF0000"),
        ("RosyBrown", "#BC8F8F"),
        ("RoyalBlue", "#4169E1"),
        ("SaddleBrown", "#8B4513"),
        ("Salmon", "#FA8072"),
        ("SandyBrown", "#F4A460"),
        ("SeaGreen", "#2E8B57"),
        ("SeaShell", "#FFF5EE"),
        ("Sienna", "#A0522D"),
        ("Silver", "#C0C0C0"),
        ("SkyBlue", "#87CEEB"),
        ("SlateBlue", "#6A5ACD"),
        ("SlateGray", "#708090"),
        ("Snow", "#FFFAFA"),
        ("SpringGreen", "#00FF7F"),
        ("SteelBlue", "#4682B4"),
        ("Tan", "#D2B48C"),
        ("Teal", "#008080"),
        ("Thistle", "#D8BFD8"),
        ("Tomato", "#FF6347"),
        ("Turquoise", "#40E0D0"),
        ("Violet", "#EE82EE"),
        ("Wheat", "#F5DEB3"),
        ("White", "#FFFFFF"),
        ("WhiteSmoke", "#F5F5F5"),
        ("Yellow", "#FFFF00"),
        ("YellowGreen", "#9ACD3"),
    ))

    safe_colors = (
        'black', 'maroon', 'green', 'navy', 'olive',
        'purple', 'teal', 'lime', 'blue', 'silver',
        'gray', 'yellow', 'fuchsia', 'aqua', 'white',
    )

    def color_name(self):
        return self.random_element(self.all_colors.keys())

    def safe_color_name(self):
        return self.random_element(self.safe_colors)

    def hex_color(self):
        return "#{0}".format(
            ("%x" %
             self.random_int(
                 1, 16777215)).ljust(
                6, '0'))

    def safe_hex_color(self):
        color = ("%x" % self.random_int(0, 255)).ljust(3, '0')
        return "#{0}{0}{1}{1}{2}{2}".format(*color)

    def rgb_color(self):
        return ','.join(map(str, (self.random_int(0, 255) for _ in range(3))))

    def rgb_css_color(self):
        return 'rgb(%s)' % ','.join(
            map(str, (self.random_int(0, 255) for _ in range(3))))



# coding=utf-8
from __future__ import unicode_literals

from collections import OrderedDict

from .. import Provider as ColorProvider

localized = True


class Provider(ColorProvider):
    all_colors = OrderedDict((
        ('Akvamarin', '#7FFFD4'),
        ('Antikna bijela', '#FAEBD7'),
        ('Azurna', '#F0FFFF'),
        ('Bež', '#F5F5DC'),
        ('Bijela', '#FFFFFF'),
        ('Bijelo bilje', '#FFFAF0'),
        ('Bjelokost', '#FFFFF0'),
        ('Blijeda kudelja', '#EEE8AA'),
        ('Blijedi badem', '#FFEBCD'),
        ('Blijedoljubičasta', '#DB7093'),
        ('Blijedotirkizna', '#AFEEEE'),
        ('Blijedozelena', '#98FB98'),
        ('Breskva', '#FFDAB9'),
        ('Brončana', '#D2B48C'),
        ('Čeličnoplava', '#4682B4'),
        ('Čičak', '#D8BFD8'),
        ('Cijan', '#00FFFF'),
        ('Čipka', '#FDF5E6'),
        ('Čokoladna', '#D2691E'),
        ('Crna', '#000000'),
        ('Crvena', '#FF0000'),
        ('Dim', '#F5F5F5'),
        ('Dodger plava', '#1E90FF'),
        ('Duboko ružičasta', '#FF1493'),
        ('Fuksija', '#FF00FF'),
        ('Gainsboro', '#DCDCDC'),
        ('Grimizna', '#DC143C'),
        ('Indigo', '#4B0082'),
        ('Jelenska koža', '#FFE4B5'),
        ('Kadetski plava', '#5F9EA0'),
        ('Kestenjasta', '#800000'),
        ('Koraljna', '#FF7F50'),
        ('Kraljevski plava', '#4169E1'),
        ('Kudelja', '#DAA520'),
        ('Lan', '#FAF0E6'),
        ('Lavanda', '#E6E6FA'),
        ('Limun', '#FFFACD'),
        ('Lipa', '#00FF00'),
        ('Ljubičasta', '#EE82EE'),
        ('Magenta', '#FF00FF'),
        ('Maslinasta', '#808000'),
        ('Medljika', '#F0FFF0'),
        ('Menta', '#F5FFFA'),
        ('Modro nebo', '#00BFFF'),
        ('Modrozelena', '#008080'),
        ('Mornarska', '#000080'),
        ('Morskozelena', '#2E8B57'),
        ('Mračno siva', '#696969'),
        ('Narančasta', '#FFA500'),
        ('Narančastocrvena', '#FF4500'),
        ('Narančastoružičasta', '#FA8072'),
        ('Noćno plava', '#191970'),
        ('Orhideja', '#DA70D6'),
        ('Papaja', '#FFEFD5'),
        ('Peru', '#CD853F'),
        ('Plava', '#0000FF'),
        ('Plavi prah', '#B0E0E6'),
        ('Plavi škriljevac', '#6A5ACD'),
        ('Plavkasta', '#F0F8FF'),
        ('Plavo cvijeće', '#6495ED'),
        ('Plavo nebo', '#87CEEB'),
        ('Plavoljubičasta', '#8A2BE2'),
        ('Porculanska', '#FFE4C4'),
        ('Prljavomaslinasta', '#6B8E23'),
        ('Proljetnozelena', '#00FF7F'),
        ('Prozirno bijela', '#F8F8FF'),
        ('Pšenica', '#F5DEB3'),
        ('Purpurna', '#800080'),
        ('Rajčica', '#FF6347'),
        ('Rumena lavanda', '#FFF0F5'),
        ('Ružičasta', '#FFC0CB'),
        ('Ružičastosmeđa', '#BC8F8F'),
        ('Siva', '#808080'),
        ('Sivi škriljevac', '#708090'),
        ('Sivožuta', '#F0E68C'),
        ('Smeđa', '#A52A2A'),
        ('Smeđe sedlo', '#8B4513'),
        ('Smeđi pijesak', '#F4A460'),
        ('Smeđkasto bijela', '#FFDEAD'),
        ('Snijeg', '#FFFAFA'),
        ('Srebrna', '#C0C0C0'),
        ('Srednja akvamarin', '#66CDAA'),
        ('Srednja crvenoljubičasta', '#C71585'),
        ('Srednja morskozelena', '#3CB371'),
        ('Srednja orhideja', '#BA55D3'),
        ('Srednja plava', '#0000CD'),
        ('Srednja proljetnozelena', '#00FA9A'),
        ('Srednja purpurna', '#9370DB'),
        ('Srednja tirkizna', '#48D1CC'),
        ('Srednje plavi škriljevac', '#7B68EE'),
        ('Svijetla čeličnoplava', '#B0C4DE'),
        ('Svijetla narančastoružičasta', '#FFA07A'),
        ('Svijetli cijan', '#E0FFFF'),
        ('Svijetlo drvo', '#DEB887'),
        ('Svijetlokoraljna', '#F08080'),
        ('Svijetlomorskozelena', '#20B2AA'),
        ('Svijetloplava', '#ADD8E6'),
        ('Svijetloružičasta', '#FFB6C1'),
        ('Svijetlosiva', '#D3D3D3'),
        ('Svijetlosivi škriljevac', '#778899'),
        ('Svijetlozelena', '#90EE90'),
        ('Svijetložuta kudelja', '#FAFAD2'),
        ('Svijetložuta', '#FFFFE0'),
        ('Šamotna opeka', '#B22222'),
        ('Školjka', '#FFF5EE'),
        ('Šljiva', '#DDA0DD'),
        ('Tamna kudelja', '#B8860B'),
        ('Tamna magenta', '#8B008B'),
        ('Tamna narančastoružičasta', '#E9967A'),
        ('Tamna orhideja', '#9932CC'),
        ('Tamna sivožuta', '#BDB76B'),
        ('Tamni cijan', '#008B8B'),
        ('Tamno zelena', '#006400'),
        ('Tamnocrvena', '#8B0000'),
        ('Tamnoljubičasta', '#9400D3'),
        ('Tamnomaslinasta', '#556B2F'),
        ('Tamnonarančasta', '#FF8C00'),
        ('Tamnoplava', '#00008B'),
        ('Tamnoplavi škriljevac', '#483D8B'),
        ('Tamnosiva', '#A9A9A9'),
        ('Tamnosivi škriljevac', '#2F4F4F'),
        ('Tamnotirkizna', '#00CED1'),
        ('Tamnozelena', '#8FBC8F'),
        ('Tirkizna', '#40E0D0'),
        ('Topla ružičasta', '#FF69B4'),
        ('Vedro nebo', '#87CEFA'),
        ('Voda', '#00FFFF'),
        ('Zelena lipa', '#32CD32'),
        ('Zelena šuma', '#228B22'),
        ('Zelena tratina', '#7CFC00'),
        ('Zelena', '#008000'),
        ('Zeleni liker', '#7FFF00'),
        ('Zelenožuta', '#ADFF2F'),
        ('Zlatna', '#FFD700'),
        ('Žućkastocrvena zemlja', '#CD5C5C'),
        ('Žućkastoružičasta', '#FFE4E1'),
        ('Žućkastosmeđa glina', '#A0522D'),
        ('Žuta svila', '#FFF8DC'),
        ('Žuta', '#FFFF00'),
        ('Žutozelena', '#9ACD3'),
    ))

    safe_colors = (
        'crna', 'kestenjasta', 'zelena', 'mornarska', 'maslinasta',
        'purpurna', 'modrozelena', 'lipa', 'plava', 'srebrna',
        'siva', 'žuta', 'fuksija', 'voda', 'bijela',
    )



# coding=utf-8

from __future__ import unicode_literals
from .. import Provider as AddressProvider


class Provider(AddressProvider):
    building_number_formats = ('#', '##', '###', '#', '##', '###',)

    street_suffixes = (
        'baan', 'boulevard', 'dreef', 'hof', 'laan', 'lei', 'pad',
        'ring', 'singel', 'steeg', 'straat', 'weg',
    )

    # the 4 digit numerical part of Belgium postal codes is between 1000 and 9999;
    # see https://nl.wikipedia.org/wiki/Postcode#Postnummers_in_België
    postcode_formats = ('%###',)

    city_formats = ('{{city}}',)

    # countries are from http://nl.wikipedia.org/wiki/ISO_3166-1
    countries = (
        'Afghanistan', 'Albanië', 'Algerije', 'Amerikaans-Samoa',
        'Amerikaanse Maagdeneilanden', 'Andorra', 'Angola', 'Anguilla',
        'Antarctica', 'Antigua en Barbuda', 'Argentinië', 'Armenië', 'Aruba',
        'Australië', 'Azerbeidzjan', "Bahama's", 'Bahrein', 'Bangladesh',
        'Barbados', 'België', 'Belize', 'Benin', 'Bermuda', 'Bhutan',
        'Bolivia', 'Bonaire, Sint Eustatius en Saba', 'Bosnië en Herzegovina',
        'Botswana', 'Bouveteiland', 'Brazilië',
        'Brits Indische Oceaanterritorium', 'Britse Maagdeneilanden', 'Brunei',
        'Bulgarije', 'Burkina Faso', 'Burundi', 'Cambodja', 'Canada',
        'Centraal-Afrikaanse Republiek', 'Chili', 'China', 'Christmaseiland',
        'Cocoseilanden', 'Colombia', 'Comoren', 'Congo-Brazzaville',
        'Congo-Kinshasa', 'Cookeilanden', 'Costa Rica', 'Cuba', 'Curaçao',
        'Cyprus', 'Denemarken', 'Djibouti', 'Dominica',
        'Dominicaanse Republiek', 'Duitsland', 'Ecuador', 'Egypte',
        'El Salvador', 'Equatoriaal-Guinea', 'Eritrea', 'Estland', 'Ethiopië',
        'Faeröer', 'Falklandeilanden', 'Fiji', 'Filipijnen', 'Finland',
        'Frankrijk', 'Frans-Guyana', 'Frans-Polynesië',
        'Franse Zuidelijke en Antarctische Gebieden', 'Gabon', 'Gambia',
        'Georgië', 'Ghana', 'Gibraltar', 'Grenada', 'Griekenland', 'Groenland',
        'Guadeloupe', 'Guam', 'Guatemala', 'Guernsey', 'Guinee',
        'Guinee-Bissau', 'Guyana', 'Haïti', 'Heard en McDonaldeilanden',
        'Honduras', 'Hongarije', 'Hongkong', 'IJsland', 'Ierland', 'India',
        'Indonesië', 'Irak', 'Iran', 'Israël', 'Italië', 'Ivoorkust',
        'Jamaica', 'Japan', 'Jemen', 'Jersey', 'Jordanië', 'Kaaimaneilanden',
        'Kaapverdië', 'Kameroen', 'Kazachstan', 'Kenia', 'Kirgizië',
        'Kiribati', 'Kleine Pacifische eilanden van de Verenigde Staten',
        'Koeweit', 'Kroatië', 'Laos', 'Lesotho', 'Letland', 'Libanon',
        'Liberia', 'Libië', 'Liechtenstein', 'Litouwen', 'Luxemburg', 'Macau',
        'Macedonië', 'Madagaskar', 'Malawi', 'Maldiven', 'Maleisië', 'Mali',
        'Malta', 'Man', 'Marokko', 'Marshalleilanden', 'Martinique',
        'Mauritanië', 'Mauritius', 'Mayotte', 'Mexico', 'Micronesia',
        'Moldavië', 'Monaco', 'Mongolië', 'Montenegro', 'Montserrat',
        'Mozambique', 'Myanmar', 'Namibië', 'Nauru', 'Nederland', 'Nepal',
        'Nicaragua', 'Nieuw-Caledonië', 'Nieuw-Zeeland', 'Niger', 'Nigeria',
        'Niue', 'Noord-Korea', 'Noordelijke Marianen', 'Noorwegen', 'Norfolk',
        'Oeganda', 'Oekraïne', 'Oezbekistan', 'Oman', 'Oost-Timor',
        'Oostenrijk', 'Pakistan', 'Palau', 'Palestina', 'Panama',
        'Papoea-Nieuw-Guinea', 'Paraguay', 'Peru', 'Pitcairneilanden', 'Polen',
        'Portugal', 'Puerto Rico', 'Qatar', 'Roemenië', 'Rusland', 'Rwanda',
        'Réunion', 'Saint Kitts en Nevis', 'Saint Lucia',
        'Saint Vincent en de Grenadines', 'Saint-Barthélemy',
        'Saint-Pierre en Miquelon', 'Salomonseilanden', 'Samoa', 'San Marino',
        'Sao Tomé en Principe', 'Saoedi-Arabië', 'Senegal', 'Servië',
        'Seychellen', 'Sierra Leone', 'Singapore', 'Sint Maarten',
        'Sint-Helena, Ascension en Tristan da Cunha', 'Sint-Maarten',
        'Slovenië', 'Slowakije', 'Soedan', 'Somalië', 'Spanje',
        'Spitsbergen en Jan Mayen', 'Sri Lanka', 'Suriname', 'Swaziland',
        'Syrië', 'Tadzjikistan', 'Taiwan', 'Tanzania', 'Thailand', 'Togo',
        'Tokelau', 'Tonga', 'Trinidad en Tobago', 'Tsjaad', 'Tsjechië',
        'Tunesië', 'Turkije', 'Turkmenistan', 'Turks- en Caicoseilanden',
        'Tuvalu', 'Uruguay', 'Vanuatu', 'Vaticaanstad', 'Venezuela',
        'Verenigd Koninkrijk', 'Verenigde Arabische Emiraten',
        'Verenigde Staten', 'Vietnam', 'Wallis en Futuna', 'Westelijke Sahara',
        'Wit-Rusland', 'Zambia', 'Zimbabwe', 'Zuid-Afrika',
        'Zuid-Georgia en de Zuidelijke Sandwicheilanden', 'Zuid-Korea',
        'Zuid-Soedan', 'Zweden', 'Zwitserland', 'Åland',
    )

    # cities as listed on "postcodezoeker"
    # http://www.postcodes-maps.be/postcodelijst.php
    cities = (
        "'s Herenelderen", "'s-Gravenvoeren", "'s-Gravenwezel", "Aaigem", "Aalbeke",
        "Aalst", "Aalter", "Aarschot", "Aarsele", "Aartrijke", "Aartselaar", "Abolens",
        "Abée", "Achel", "Achet", "Achêne", "Acosse", "Acoz", "Adegem", "Adinkerke",
        "Affligem", "Afsnee", "Agimont", "Aineffe", "Aische-en-Refail", "Aiseau",
        "Aiseau-Presles", "Aisemont", "Alken", "Alle", "Alleur", "Alsemberg",
        "Alveringem", "Amay", "Amberloup", "Ambly", "Ambresin", "Amel", "Amonines",
        "Amougies", "Ampsin", "Andenne", "Anderlecht", "Anderlues", "Andrimont",
        "Angleur", "Angre", "Angreau", "Anhée", "Anlier", "Anloy", "Annevoie-Rouillon",
        "Ans", "Anseremme", "Anseroeul", "Antheit", "Anthisnes", "Anthée", "Antoing",
        "Antwerpen", "Anvaing", "Anzegem", "Appels", "Appelterre-Eichem", "Arbre",
        "Arbrefontaine", "Arc-Ainières", "Arc-Wattripont", "Archennes", "Ardooie",
        "Arendonk", "Argenteau", "Arlon", "Arquennes", "Arsimont", "Arville", "As",
        "Aspelare", "Asper", "Asquillies", "Asse", "Assebroek", "Assenede", "Assenois",
        "Assent", "Assesse", "Astene", "Ath", "Athis", "Athus", "Attenhoven", "Attenrode",
        "Attert", "Attre", "Aubange", "Aubechies", "Aubel", "Aublain", "Auby-sur-Semois",
        "Audregnies", "Aulnois", "Autelbas", "Autre-Eglise", "Autreppe", "Auvelais",
        "Ave-et-Auffe", "Avekapelle", "Avelgem", "Avennes", "Averbode",
        "Avernas-le-Bauduin", "Avin", "Awans", "Awenne", "Awirs", "Aye", "Ayeneux",
        "Aywaille", "Baaigem", "Baal", "Baardegem", "Baarle-Hertog", "Baasrode",
        "Bachte-Maria-Leerne", "Baelen", "Bagimont", "Baileux", "Bailièvre", "Baillamont",
        "Bailleul", "Baillonville", "Baisieux", "Baisy-Thy", "Balegem", "Balen",
        "Balâtre", "Bambrugge", "Bande", "Barbençon", "Barchon", "Baronville", "Barry",
        "Barvaux-Condroz", "Barvaux-sur-Ourthe", "Bas-Oha", "Basse-Bodeux", "Bassenge",
        "Bassevelde", "Bassilly", "Bastogne", "Basècles", "Batsheers", "Battice",
        "Battignies", "Baudour", "Bauffe", "Baugnies", "Baulers", "Bavegem", "Bavikhove",
        "Bazel", "Beaufays", "Beaumont", "Beauraing", "Beausaint", "Beauvoorde",
        "Beauwelz", "Beclers", "Beek", "Beerlegem", "Beernem", "Beerse", "Beersel",
        "Beerst", "Beert", "Beervelde", "Beerzel", "Beez", "Beffe", "Begijnendijk",
        "Beho", "Beigem", "Bekegem", "Bekkerzeel", "Bekkevoort", "Belgrade", "Bellaire",
        "Bellecourt", "Bellefontaine", "Bellegem", "Bellem", "Bellevaux",
        "Bellevaux-Ligneuville", "Bellingen", "Beloeil", "Belsele", "Ben-Ahin", "Bende",
        "Berbroek", "Berchem", "Berendrecht", "Berg", "Bergilers", "Beringen", "Berlaar",
        "Berlare", "Berlingen", "Berloz", "Berneau", "Bernissart", "Bersillies-l'Abbaye",
        "Bertem", "Bertogne", "Bertrix", "Bertrée", "Berzée", "Beselare", "Betekom",
        "Bettincourt", "Beuzet", "Bevekom", "Bevel", "Bever", "Bevercé", "Bevere",
        "Beveren-Leie", "Beveren-Roeselare", "Beveren-Waas", "Beveren-aan-den-Ijzer",
        "Beverlo", "Beverst", "Beyne-Heusay", "Bienne-lez-Happart", "Bierbeek", "Biercée",
        "Bierges", "Bierghes", "Bierset", "Bierwart", "Biesme", "Biesme-sous-Thuin",
        "Biesmerée", "Biez", "Bihain", "Bikschote", "Bilstain", "Bilzen", "Binche",
        "Binderveld", "Binkom", "Bioul", "Bissegem", "Bizet", "Bièvre", "Blaasveld",
        "Blaimont", "Blandain", "Blanden", "Blankenberge", "Blaregnies", "Blaton",
        "Blaugies", "Blehen", "Bleid", "Bleret", "Blicquy", "Blégny", "Bléharies",
        "Bocholt", "Boechout", "Boekhout", "Boekhoute", "Boezinge", "Bogaarden", "Bohan",
        "Boignée", "Boirs", "Bois-d'Haine", "Bois-de-Lessines", "Bois-de-Villers",
        "Bois-et-Borsu", "Bolinne", "Bolland", "Bomal", "Bomal-sur-Ourthe", "Bombaye",
        "Bommershoven", "Bon-Secours", "Boncelles", "Boneffe", "Bonheiden", "Boninne",
        "Bonlez", "Bonnert", "Bonneville", "Bonsin", "Booischot", "Booitshoeke", "Boom",
        "Boorsem", "Boortmeerbeek", "Borchtlombeek", "Borgerhout", "Borgloon", "Borlez",
        "Borlo", "Borlon", "Bornem", "Bornival", "Borsbeek", "Borsbeke", "Bossière",
        "Bossuit", "Bossut-Gottechain", "Bost", "Bothey", "Bottelare", "Bouffioulx",
        "Bouge", "Bougnies", "Bouillon", "Bourlers", "Bourseigne-Neuve",
        "Bourseigne-Vieille", "Boussoit", "Boussu", "Boussu-en-Fagne",
        "Boussu-lez-Walcourt", "Bousval", "Boutersem", "Bouvignes-sur-Meuse",
        "Bouvignies", "Bouwel", "Bovekerke", "Bovelingen", "Bovenistier", "Bovesse",
        "Bovigny", "Boëlhe", "Bra", "Braffe", "Braibant", "Braine-l'Alleud",
        "Braine-le-Château", "Braine-le-Comte", "Braives", "Brakel", "Branchon", "Bras",
        "Brasmenil", "Brasschaat", "Bray", "Brecht", "Bredene", "Bree", "Breendonk",
        "Bressoux", "Briegden", "Brielen", "Broechem", "Broekom", "Brugelette", "Brugge",
        "Brunehaut", "Brussegem", "Brussel", "Brustem", "Bruyelle", "Brye", "Brûly",
        "Brûly-de-Pesche", "Budingen", "Buggenhout", "Buissenal", "Buissonville",
        "Buizingen", "Buken", "Bulskamp", "Bunsbeek", "Burcht", "Burdinne", "Bure",
        "Burg-Reuland", "Burst", "Bury", "Buvingen", "Buvrinnes", "Buzenol", "Buzet",
        "Büllingen", "Bütgenbach", "Callenelle", "Calonne", "Cambron-Casteau",
        "Cambron-Saint-Vincent", "Carlsbourg", "Carnières", "Casteau", "Castillon",
        "Celles", "Cerfontaine", "Chaineux", "Chairière", "Champion", "Champlon",
        "Chanly", "Chantemelle", "Chapelle-lez-Herlaimont", "Chapelle-à-Oie",
        "Chapelle-à-Wattines", "Chapon-Seraing", "Charleroi", "Charneux", "Chassepierre",
        "Chastre", "Chastre-Villeroux-Blanmont", "Chastrès", "Chaudfontaine",
        "Chaumont-Gistoux", "Chaussée-Notre-Dame-Louvignies", "Cherain", "Cheratte",
        "Chercq", "Chevetogne", "Chevron", "Chimay", "Chiny", "Chièvres", "Chokier",
        "Châtelet", "Châtelineau", "Châtillon", "Chênée", "Ciergnon", "Ciney", "Ciplet",
        "Ciply", "Clabecq", "Clavier", "Clermont", "Clermont-sous-Huy", "Cognelée",
        "Colfontaine", "Comblain-Fairon", "Comblain-au-Pont", "Comblain-la-Tour",
        "Conneux", "Corbais", "Corbion", "Cordes", "Corenne", "Cornesse", "Cornimont",
        "Corroy-le-Château", "Corroy-le-Grand", "Corswarem", "Cortil-Noirmont",
        "Cortil-Wodon", "Couillet", "Cour-sur-Heure", "Courcelles", "Courrière",
        "Court-Saint-Etienne", "Couthuin", "Coutisse", "Couture-Saint-Germain", "Couvin",
        "Cras-Avernas", "Crehen", "Crisnée", "Croix-lez-Rouveroy", "Crombach", "Crupet",
        "Cuesmes", "Cugnon", "Cul-des-Sarts", "Custinne", "Cérexhe-Heuseux",
        "Céroux-Mousty", "Dadizele", "Dailly", "Daknam", "Dalhem", "Damme", "Dampicourt",
        "Dampremy", "Darion", "Daussois", "Daussoulx", "Dave", "Daverdisse", "De Haan",
        "De Klinge", "De Moeren", "De Panne", "De Pinte", "Deerlijk", "Deftinge",
        "Deinze", "Denderbelle", "Denderhoutem", "Denderleeuw", "Dendermonde",
        "Denderwindeke", "Dentergem", "Denée", "Dergneau", "Dessel", "Desselgem",
        "Destelbergen", "Desteldonk", "Deurle", "Deurne", "Deux-Acren", "Dhuy",
        "Diepenbeek", "Diest", "Diets-Heur", "Dikkebus", "Dikkele", "Dikkelvenne",
        "Diksmuide", "Dilbeek", "Dilsen-Stokkem", "Dinant", "Dion", "Dion-Valmont",
        "Dison", "Dochamps", "Doel", "Dohan", "Doische", "Dolembreux", "Donceel",
        "Dongelberg", "Donk", "Donstiennes", "Dorinne", "Dormaal", "Dottenijs", "Dour",
        "Dourbes", "Dranouter", "Driekapellen", "Drieslinter", "Drogenbos", "Drongen",
        "Dréhance", "Dudzele", "Duffel", "Duisburg", "Duras", "Durbuy", "Durnal", "Dworp",
        "Eben-Emael", "Ebly", "Ecaussinnes", "Ecaussinnes-Lalaing",
        "Ecaussinnes-d'Enghien", "Edegem", "Edelare", "Edingen", "Eeklo", "Eernegem",
        "Egem", "Eggewaartskapelle", "Eghezée", "Ehein", "Eigenbilzen", "Eindhout",
        "Eine", "Eisden", "Eke", "Ekeren", "Eksaarde", "Eksel", "Elen", "Elene",
        "Elewijt", "Eliksem", "Elingen", "Ellemelle", "Ellezelles",
        "Ellignies-Sainte-Anne", "Ellignies-lez-Frasnes", "Ellikom", "Elouges", "Elsegem",
        "Elsenborn", "Elsene", "Elst", "Elverdinge", "Elversele", "Emblem", "Embourg",
        "Emelgem", "Emines", "Emptinne", "Ename", "Engelmanshoven", "Engis", "Enines",
        "Ensival", "Epinois", "Eppegem", "Eprave", "Erbaut", "Erbisoeul", "Ere",
        "Erembodegem", "Erezée", "Ermeton-sur-Biert", "Ernage", "Erneuville", "Ernonheid",
        "Erondegem", "Erpe", "Erpe-Mere", "Erpent", "Erpion", "Erps-Kwerps",
        "Erquelinnes", "Erquennes", "Ertvelde", "Erwetegem", "Escanaffles", "Esen",
        "Esneux", "Esplechin", "Esquelmes", "Essen", "Essene", "Estaimbourg",
        "Estaimpuis", "Estinnes", "Estinnes-au-Mont", "Estinnes-au-Val", "Etalle", "Ethe",
        "Etikhove", "Ettelgem", "Etterbeek", "Eugies", "Eupen", "Evegnée", "Evelette",
        "Everbeek", "Everberg", "Evere", "Evergem", "Evregnies", "Evrehailles",
        "Eynatten", "Ezemaal", "Fagnolle", "Faimes", "Falaën", "Falisolle", "Fallais",
        "Falmagne", "Falmignoul", "Familleureux", "Farciennes", "Faulx-les-Tombes",
        "Fauroeulx", "Fauvillers", "Faymonville", "Fays-les-Veneurs", "Fayt-le-Franc",
        "Fayt-lez-Manage", "Felenne", "Feluy", "Feneur", "Fernelmont", "Ferrières",
        "Feschaux", "Fexhe-Slins", "Fexhe-le-Haut-Clocher", "Filot", "Finnevaux",
        "Fize-Fontaine", "Fize-le-Marsal", "Flamierge", "Flavion", "Flawinne", "Fleurus",
        "Floreffe", "Florennes", "Florenville", "Floriffoux", "Florée", "Flostoy",
        "Flémalle", "Flémalle-Grande", "Flémalle-Haute", "Flénu", "Fléron", "Flône",
        "Focant", "Folx-les-Caves", "Fontaine-Valmont", "Fontaine-l'Evêque", "Fontenelle",
        "Fontenoille", "Fontenoy", "Fooz", "Forchies-la-Marche", "Forest", "Forges",
        "Forges-Philippe", "Forrières", "Forville", "Forêt", "Fosse", "Fosses-la-Ville",
        "Fouleng", "Fourbechies", "Foy-Notre-Dame", "Fraipont", "Fraire", "Fraiture",
        "Frameries", "Framont", "Franc-Waret", "Franchimont", "Francorchamps", "Franière",
        "Frasnes", "Frasnes-lez-Anvaing", "Frasnes-lez-Buissenal",
        "Frasnes-lez-Gosselies", "Freloux", "Freux", "Froidchapelle", "Froidfontaine",
        "Froidmont", "Fronville", "Froyennes", "Fumal", "Furfooz", "Furnaux", "Gaasbeek",
        "Gages", "Gallaix", "Galmaarden", "Ganshoren", "Gaurain-Ramecroix", "Gavere",
        "Gedinne", "Geel", "Geer", "Geest-Gérompont-Petit-Rosière", "Geetbets",
        "Gelbressée", "Gelinden", "Gellik", "Gelrode", "Geluveld", "Geluwe", "Gembes",
        "Gembloux", "Gemmenich", "Genappe", "Genk", "Genly", "Genoelselderen", "Gent",
        "Gentbrugge", "Gentinnes", "Genval", "Geraardsbergen", "Gerdingen", "Gerin",
        "Gerpinnes", "Gestel", "Gesves", "Ghislenghien", "Ghlin", "Ghoy", "Gibecq",
        "Gierle", "Gijverinkhove", "Gijzegem", "Gijzelbrechtegem", "Gijzenzele", "Gilly",
        "Gimnée", "Gingelom", "Gistel", "Gits", "Givry", "Glabais", "Glabbeek-Zuurbemde",
        "Glain", "Gleixhe", "Glimes", "Glons", "Gochenée", "Godarville", "Godinne",
        "Godveerdegem", "Goeferdinge", "Goegnies-Chaussée", "Goesnes", "Goetsenhoven",
        "Gomzé-Andoumont", "Gondregnies", "Gonrieux", "Gontrode", "Gooik", "Gors-Opleeuw",
        "Gorsem", "Gosselies", "Gotem", "Gottem", "Gottignies", "Gougnies", "Gourdinne",
        "Goutroux", "Gouvy", "Gouy-lez-Piéton", "Gozée", "Goé", "Graide", "Grammene",
        "Grand-Axhe", "Grand-Hallet", "Grand-Halleux", "Grand-Leez", "Grand-Manil",
        "Grand-Rechain", "Grand-Reng", "Grand-Rosière-Hottomont", "Grandglise",
        "Grandhan", "Grandmenil", "Grandmetz", "Grandrieu", "Grandville", "Grandvoir",
        "Grapfontaine", "Graty", "Graux", "Grazen", "Grembergen", "Grez-Doiceau",
        "Grimbergen", "Grimminge", "Grivegnée", "Grobbendonk", "Groot-Bijgaarden",
        "Groot-Gelmen", "Groot-Loon", "Gros-Fays", "Grosage", "Grote-Brogel",
        "Grote-Spouwen", "Grotenberge", "Gruitrode", "Grune", "Grupont", "Grâce-Berleur",
        "Grâce-Hollogne", "Guignies", "Guigoven", "Guirsch", "Gullegem", "Gutschoven",
        "Gérompont", "Gérouville", "Haacht", "Haaltert", "Haasdonk", "Haasrode", "Habay",
        "Habay-la-Neuve", "Habay-la-Vieille", "Habergy", "Haccourt", "Hachy",
        "Hacquegnies", "Haillot", "Haine-Saint-Paul", "Haine-Saint-Pierre", "Hainin",
        "Hakendover", "Halanzy", "Halen", "Hallaar", "Halle", "Halle-Booienhoven",
        "Halleux", "Halma", "Halmaal", "Haltinne", "Ham", "Ham-sur-Heure",
        "Ham-sur-Heure-Nalinnes", "Ham-sur-Sambre", "Hamipré", "Hamme", "Hamme-Mille",
        "Hamoir", "Hamois", "Hamont", "Hamont-Achel", "Hampteau", "Han-sur-Lesse",
        "Handzame", "Haneffe", "Hannut", "Hannêche", "Hanret", "Hansbeke",
        "Hantes-Wihéries", "Hanzinelle", "Hanzinne", "Harchies", "Harelbeke", "Haren",
        "Haren-Borgloon", "Haren-Tongeren", "Hargimont", "Harmignies", "Harnoncourt",
        "Harre", "Harsin", "Harveng", "Harzé", "Hasselt", "Hastière", "Hastière-Lavaux",
        "Hastière-par-Delà", "Hatrival", "Haulchin", "Hauset", "Haut-Fays", "Haut-Ittre",
        "Haut-le-Wastia", "Hautrage", "Havay", "Havelange", "Haversin", "Havinnes",
        "Havré", "Hechtel", "Hechtel-Eksel", "Heer", "Heers", "Hees", "Heestert",
        "Heffen", "Heikruis", "Heindonk", "Heinsch", "Heist-aan-Zee", "Heist-op-den-Berg",
        "Hekelgem", "Heks", "Helchteren", "Heldergem", "Helen-Bos", "Helkijn",
        "Hellebecq", "Hemelveerdegem", "Hemiksem", "Hemptinne", "Hemptinne-lez-Florennes",
        "Hendrieken", "Henis", "Hennuyères", "Henri-Chapelle", "Henripont", "Hensies",
        "Heppen", "Heppenbach", "Heppignies", "Herbeumont", "Herchies", "Herderen",
        "Herdersem", "Herent", "Herentals", "Herenthout", "Herfelingen", "Hergenrath",
        "Herk-de-Stad", "Hermalle-sous-Argenteau", "Hermalle-sous-Huy",
        "Hermeton-sur-Meuse", "Hermée", "Herne", "Herquegies", "Herseaux", "Herselt",
        "Herstal", "Herstappe", "Hertain", "Herten", "Hertsberge", "Herve", "Herzele",
        "Heule", "Heure", "Heure-le-Romain", "Heurne", "Heusden", "Heusden-Zolder",
        "Heusy", "Heuvelland", "Hever", "Heverlee", "Heyd", "Hillegem", "Hingene",
        "Hingeon", "Hives", "Hoboken", "Hodeige", "Hodister", "Hody", "Hoegaarden",
        "Hoeilaart", "Hoeke", "Hoelbeek", "Hoeleden", "Hoepertingen", "Hoeselt",
        "Hoevenen", "Hofstade", "Hogne", "Hognoul", "Hollain", "Hollange", "Hollebeke",
        "Hollogne-aux-Pierres", "Hollogne-sur-Geer", "Holsbeek", "Hombeek", "Hombourg",
        "Hompré", "Hondelange", "Honnay", "Honnelles", "Hooglede", "Hoogstade",
        "Hoogstraten", "Horebeke", "Horion-Hozémont", "Hornu", "Horpmaal", "Horrues",
        "Hotton", "Houdemont", "Houdeng-Aimeries", "Houdeng-Goegnies", "Houdremont",
        "Houffalize", "Hour", "Housse", "Houtain-Saint-Siméon", "Houtain-le-Val",
        "Houtaing", "Houtave", "Houtem", "Houthalen", "Houthalen-Helchteren", "Houthem",
        "Houthulst", "Houtvenne", "Houwaart", "Houx", "Houyet", "Hove", "Hoves",
        "Howardries", "Huccorgne", "Huise", "Huissignies", "Huizingen", "Huldenberg",
        "Hulshout", "Hulsonniaux", "Hulste", "Humain", "Humbeek", "Hundelgem", "Huppaye",
        "Huy", "Hyon", "Hélécine", "Hérinnes-lez-Pecq", "Héron", "Hévillers", "Ichtegem",
        "Iddergem", "Idegem", "Ieper", "Impe", "Incourt", "Ingelmunster", "Ingooigem",
        "Irchonwelz", "Isières", "Isnes", "Itegem", "Itterbeek", "Ittre", "Ivoz-Ramet",
        "Izegem", "Izel", "Izenberge", "Izier", "Jabbeke", "Jalhay", "Jallet", "Jamagne",
        "Jambes", "Jamiolle", "Jamioulx", "Jamoigne", "Jandrain-Jandrenouille", "Jauche",
        "Jauchelette", "Javingue", "Jehay", "Jehonville", "Jemappes", "Jemelle",
        "Jemeppe-sur-Meuse", "Jemeppe-sur-Sambre", "Jeneffe", "Jesseren", "Jette", "Jeuk",
        "Jodoigne", "Jodoigne-Souveraine", "Jollain-Merlin", "Joncret", "Julémont",
        "Jumet", "Jupille-sur-Meuse", "Juprelle", "Jurbise", "Juseret", "Kaaskerke",
        "Kachtem", "Kaggevinne", "Kain", "Kalken", "Kallo", "Kallo-Kieldrecht",
        "Kalmthout", "Kampenhout", "Kanegem", "Kanne", "Kapelle-op-den-Bos", "Kapellen",
        "Kaprijke", "Kaster", "Kasterlee", "Kaulille", "Keerbergen", "Keiem", "Kelmis",
        "Kemexhe", "Kemmel", "Kemzeke", "Kerkhove", "Kerkom", "Kerkom-bij-Sint-Truiden",
        "Kerksken", "Kermt", "Kerniel", "Kersbeek-Miskom", "Kessel", "Kessel-Lo",
        "Kessenich", "Kester", "Kettenis", "Keumiée", "Kieldrecht", "Kinrooi",
        "Klein-Gelmen", "Kleine-Brogel", "Kleine-Spouwen", "Klemskerke", "Klerken",
        "Kluisbergen", "Kluizen", "Knesselare", "Knokke", "Knokke-Heist", "Kobbegem",
        "Koekelare", "Koekelberg", "Koersel", "Koksijde", "Kolmont-Borgloon",
        "Kolmont-Tongeren", "Komen", "Komen-Waasten", "Koningshooikt", "Koninksem",
        "Kontich", "Kooigem", "Koolkerke", "Koolskamp", "Korbeek-Dijle", "Korbeek-Lo",
        "Kortemark", "Kortenaken", "Kortenberg", "Kortessem", "Kortijs", "Kortrijk",
        "Kortrijk-Dutsel", "Kozen", "Kraainem", "Krombeke", "Kruibeke", "Kruishoutem",
        "Kumtich", "Kuringen", "Kuttekoven", "Kuurne", "Kwaadmechelen", "Kwaremont", "La",
        "La Bruyère", "La Glanerie", "La Gleize", "La Hestre", "La Hulpe", "La Louvière",
        "La bouverie", "La-Roche-en-Ardenne", "Laakdal", "Laar", "Laarne", "Labuissière",
        "Lacuisine", "Ladeuze", "Laforêt", "Lahamaide", "Laken", "Lamain", "Lambermont",
        "Lambusart", "Lamine", "Lamontzée", "Lamorteau", "Lampernisse", "Lanaken",
        "Lanaye", "Landegem", "Landelies", "Landen", "Landenne", "Landskouter", "Laneffe",
        "Langdorp", "Langemark", "Langemark-Poelkapelle", "Lanklaar", "Lanquesaint",
        "Lantin", "Lantremange", "Laplaigne", "Lapscheure", "Lasne",
        "Lasne-Chapelle-Saint-Lambert", "Lathuy", "Latinne", "Latour", "Lauw", "Lauwe",
        "Lavacherie", "Lavaux-Sainte-Anne", "Lavoir", "Le Mesniel", "Le Roeulx",
        "Le Roux", "Lebbeke", "Lede", "Ledeberg", "Ledegem", "Leefdaal", "Leerbeek",
        "Leernes", "Leers-Nord", "Leers-et-Fosteau", "Leest", "Leeuwergem", "Leffinge",
        "Leignon", "Leisele", "Leke", "Lembeek", "Lembeke", "Lemberge", "Lendelede",
        "Lennik", "Lens", "Lens-Saint-Remy", "Lens-Saint-Servais", "Lens-sur-Geer",
        "Leopoldsburg", "Les Avins", "Les Bons", "Les Bulles", "Les Hayons",
        "Les Waleffes", "Lesdain", "Lessines", "Lessive", "Lesterny", "Lesve",
        "Lettelingen", "Letterhoutem", "Leugnies", "Leupegem", "Leut", "Leuven", "Leuze",
        "Leuze-en-Hainaut", "Leval-Chaudeville", "Leval-Trahegnies", "Liberchies",
        "Libin", "Libramont", "Libramont-Chevigny", "Lichtaart", "Lichtervelde",
        "Liedekerke", "Lieferinge", "Lier", "Lierde", "Lierneux", "Liernu", "Liers",
        "Liezele", "Ligne", "Ligney", "Ligny", "Lille", "Lillo", "Lillois-Witterzée",
        "Limal", "Limbourg", "Limelette", "Limerlé", "Limont", "Lincent", "Linden",
        "Linkebeek", "Linkhout", "Linsmeau", "Lint", "Linter", "Lippelo", "Lisogne",
        "Lissewege", "Lives-sur-Meuse", "Lixhe", "Liège", "Lo", "Lo-Reninge", "Lobbes",
        "Lochristi", "Lodelinsart", "Loenhout", "Loker", "Lokeren", "Loksbergen",
        "Lombardsijde", "Lombise", "Lommel", "Lommersweiler", "Lompret", "Lomprez",
        "Loncin", "Londerzeel", "Longchamps", "Longlier", "Longueville", "Longvilly",
        "Lontzen", "Lonzée", "Loonbeek", "Loppem", "Lorcé", "Lot", "Lotenhulle",
        "Louette-Saint-Denis", "Louette-Saint-Pierre", "Loupoigne", "Louvain-la-Neuve",
        "Louveigné", "Lovendegem", "Lovenjoel", "Loverval", "Loyers", "Lubbeek",
        "Luingne", "Lummen", "Lustin", "Luttre", "Léglise", "Maarke-Kerkem", "Maarkedal",
        "Maaseik", "Maasmechelen", "Mabompré", "Machelen", "Macon", "Macquenoise",
        "Maffe", "Maffle", "Magnée", "Maillen", "Mainvault", "Maisières", "Maissin",
        "Maizeret", "Mal", "Maldegem", "Malderen", "Malempré", "Malle", "Malmedy",
        "Malonne", "Malvoisin", "Malèves-Sainte-Marie-Wastines", "Manage", "Manderfeld",
        "Manhay", "Mannekensvere", "Maransart", "Marbais", "Marbaix", "Marbehan",
        "Marche-en-Famenne", "Marche-les-Dames", "Marche-lez-Ecaussinnes",
        "Marchienne-au-Pont", "Marchin", "Marchipont", "Marchovelette", "Marcinelle",
        "Marcourt", "Marenne", "Mariakerke", "Mariekerke", "Mariembourg", "Marilles",
        "Mark", "Marke", "Markegem", "Marneffe", "Marquain", "Martelange", "Martenslinde",
        "Martouzin-Neuville", "Masbourg", "Masnuy-Saint-Jean", "Masnuy-Saint-Pierre",
        "Massemen", "Massenhoven", "Matagne-la-Grande", "Matagne-la-Petite", "Mater",
        "Maubray", "Maulde", "Maurage", "Mazenzele", "Mazy", "Mazée", "Mechelen",
        "Mechelen-Bovelingen", "Mechelen-aan-de-Maas", "Meeffe", "Meensel-Kiezegem",
        "Meer", "Meerbeek", "Meerbeke", "Meerdonk", "Meerhout", "Meerle", "Meeswijk",
        "Meetkerke", "Meeuwen", "Meeuwen-Gruitrode", "Mehaigne", "Meigem", "Meilegem",
        "Meise", "Meix-devant-Virton", "Meix-le-Tige", "Melden", "Meldert", "Melen",
        "Melkwezer", "Melle", "Mellery", "Melles", "Mellet", "Mellier", "Melsbroek",
        "Melsele", "Melsen", "Membach", "Membre", "Membruggen", "Mendonk", "Menen",
        "Merbes-Sainte-Marie", "Merbes-le-Château", "Merchtem", "Merdorp", "Mere",
        "Merelbeke", "Merendree", "Merkem", "Merksem", "Merksplas", "Merlemont", "Mesen",
        "Meslin-l'Evêque", "Mesnil-Eglise", "Mesnil-Saint-Blaise", "Mespelare",
        "Messancy", "Messelbroek", "Mesvin", "Mettekoven", "Mettet", "Meulebeke", "Meux",
        "Meyerode", "Michelbeke", "Micheroux", "Middelburg", "Middelkerke",
        "Mielen-boven-Aalst", "Mignault", "Millen", "Milmort", "Minderhout", "Mirwart",
        "Miécret", "Modave", "Moelingen", "Moen", "Moerbeke", "Moerbeke-Waas", "Moere",
        "Moerkerke", "Moerzeke", "Moeskroen", "Moha", "Mohiville", "Moignelée", "Moircy",
        "Mol", "Molenbaix", "Molenbeek-Wersbeek", "Molenbeersel", "Molenstede", "Mollem",
        "Momalle", "Momignies", "Monceau-Imbrechies", "Monceau-en-Ardenne",
        "Monceau-sur-Sambre", "Mons", "Mons-lez-Liège", "Monstreux", "Mont",
        "Mont-Gauthier", "Mont-Saint-André", "Mont-Saint-Aubert", "Mont-Saint-Guibert",
        "Mont-Sainte-Aldegonde", "Mont-Sainte-Geneviève", "Mont-de-l'Enclus",
        "Mont-sur-Marchienne", "Montbliart", "Montegnée", "Montenaken",
        "Montignies-Saint-Christophe", "Montignies-lez-Lens", "Montignies-sur-Roc",
        "Montignies-sur-Sambre", "Montigny-le-Tilleul", "Montleban", "Montroeul-au-Bois",
        "Montroeul-sur-Haine", "Montzen", "Moorsel", "Moorsele", "Moorslede", "Moortsele",
        "Mopertingen", "Moregem", "Moresnet", "Morhet", "Morialmé", "Morkhoven",
        "Morlanwelz", "Morlanwelz-Mariemont", "Mormont", "Mornimont", "Mortier",
        "Mortroux", "Mortsel", "Morville", "Moulbaix", "Mourcourt", "Moustier",
        "Moustier-sur-Sambre", "Mouzaive", "Moxhe", "Mozet", "Muizen", "Mullem",
        "Munkzwalm", "Muno", "Munsterbilzen", "Munte", "Musson", "Mussy-la-Ville", "My",
        "Méan", "Mélin", "Mévergnies-lez-Lens", "Naast", "Nadrin", "Nafraiture",
        "Nalinnes", "Namur", "Namêche", "Nandrin", "Naninne", "Naomé", "Nassogne",
        "Natoye", "Nazareth", "Neder-over-Heembeek", "Nederboelare", "Nederbrakel",
        "Nederename", "Nederhasselt", "Nederokkerzeel", "Nederzwalm-Hermelgem",
        "Neerglabbeek", "Neerharen", "Neerhespen", "Neerheylissem", "Neerijse",
        "Neerlanden", "Neerlinter", "Neeroeteren", "Neerpelt", "Neerrepen", "Neervelp",
        "Neerwaasten", "Neerwinden", "Neigem", "Nerem", "Nessonvaux", "Nethen",
        "Nettinne", "Neu-Moresnet", "Neufchâteau", "Neufmaison", "Neufvilles", "Neupré",
        "Neuville", "Neuville-en-Condroz", "Nevele", "Niel", "Niel-bij-As",
        "Niel-bij-Sint-Truiden", "Nieuwenhove", "Nieuwenrode", "Nieuwerkerken",
        "Nieuwkapelle", "Nieuwkerke", "Nieuwkerken-Waas", "Nieuwmunster", "Nieuwpoort",
        "Nieuwrode", "Nijlen", "Nil-Saint-Vincent-Saint-Martin", "Nimy", "Ninove",
        "Nismes", "Nivelles", "Niverlée", "Nives", "Nobressart", "Nodebais", "Noduwez",
        "Noirchain", "Noirefontaine", "Noiseux", "Nokere", "Nollevaux", "Noorderwijk",
        "Noordschote", "Nossegem", "Nothomb", "Nouvelles", "Noville", "Noville-les-Bois",
        "Noville-sur-Méhaigne", "Nukerke", "Néchin", "Obaix", "Obigies", "Obourg",
        "Ochamps", "Ocquier", "Odeigne", "Odeur", "Oedelem", "Oekene", "Oelegem", "Oeren",
        "Oeselgem", "Oetingen", "Oeudeghien", "Oevel", "Offagne", "Ogy", "Ohain", "Ohey",
        "Oignies-en-Thiérache", "Oisquercq", "Oizy", "Okegem", "Olen", "Oleye",
        "Ollignies", "Olloy-sur-Viroin", "Olmen", "Olne", "Olsene", "Omal", "Ombret",
        "Omezée", "On", "Onhaye", "Onkerzele", "Onnezies", "Onoz",
        "Onze-Lieve-Vrouw-Lombeek", "Onze-Lieve-Vrouw-Waver", "Ooigem", "Ooike",
        "Oombergen", "Oorbeek", "Oordegem", "Oostakker", "Oostduinkerke", "Oosteeklo",
        "Oostende", "Oosterzele", "Oostham", "Oostkamp", "Oostkerke-Damme",
        "Oostkerke-Diksmuide", "Oostmalle", "Oostnieuwkerke", "Oostrozebeke",
        "Oostvleteren", "Oostwinkel", "Opbrakel", "Opdorp", "Opglabbeek", "Opgrimbie",
        "Ophain-Bois-Seigneur-Isaac", "Ophasselt", "Opheers", "Opheylissem", "Ophoven",
        "Opitter", "Oplinter", "Opoeteren", "Opont", "Opprebais", "Oppuurs", "Opvelp",
        "Opwijk", "Orbais", "Orchimont", "Orcq", "Ordingen", "Oret", "Oreye", "Orgeo",
        "Ormeignies", "Orp-Jauche", "Orp-le-Grand", "Orroir", "Orsmaal-Gussenhoven",
        "Ortho", "Ostiches", "Otegem", "Oteppe", "Othée", "Otrange", "Ottenburg",
        "Ottergem", "Ottignies", "Ottignies-Louvain-la-Neuve", "Oud-Heverlee",
        "Oud-Turnhout", "Oudegem", "Oudekapelle", "Oudenaarde", "Oudenaken", "Oudenburg",
        "Oudergem", "Ouffet", "Ougrée", "Oupeye", "Outer", "Outgaarden", "Outrelouxhe",
        "Outrijve", "Ouwegem", "Overboelare", "Overhespen", "Overijse", "Overmere",
        "Overpelt", "Overrepen", "Overwinden", "Paal", "Paifve", "Pailhe", "Paliseul",
        "Pamel", "Papignies", "Parike", "Passendale", "Patignies", "Paturages",
        "Paulatem", "Pecq", "Peer", "Peissant", "Pellaines", "Pellenberg", "Pepingen",
        "Pepinster", "Perk", "Pervijze", "Perwez", "Perwez-Haillot", "Pesche", "Pessoux",
        "Petegem-aan-de-Leie", "Petegem-aan-de-Schelde", "Petigny", "Petit-Fays",
        "Petit-Hallet", "Petit-Rechain", "Petit-Roeulx-lez-Braine",
        "Petit-Roeulx-lez-Nivelles", "Petit-Thier", "Petite-Chapelle", "Peutie",
        "Philippeville", "Pipaix", "Piringen", "Pironchamps", "Pittem", "Piéton",
        "Piétrain", "Piétrebais", "Plainevaux", "Plancenoit", "Ploegsteert", "Plombières",
        "Poederlee", "Poeke", "Poelkapelle", "Poesele", "Pollare", "Polleur",
        "Pollinkhove", "Pommeroeul", "Pondrôme", "Pont-de-Loup", "Pont-à-Celles",
        "Pontillas", "Poperinge", "Poppel", "Popuelles", "Porcheresse", "Pottes",
        "Poucet", "Poulseur", "Poupehan", "Pousset", "Presgaux", "Presles",
        "Profondeville", "Proven", "Pry", "Pulderbos", "Pulle", "Purnode", "Pussemange",
        "Putte", "Puurs", "Péronnes-lez-Antoing", "Péronnes-lez-Binche", "Péruwelz",
        "Quaregnon", "Quartes", "Quenast", "Queue-du-Bois", "Quevaucamps", "Quiévrain",
        "Quévy", "Quévy-le-Grand", "Quévy-le-Petit", "Rachecourt", "Racour", "Raeren",
        "Ragnies", "Rahier", "Ramegnies", "Ramegnies-Chin", "Ramelot", "Ramillies-Offus",
        "Ramsdonk", "Ramsel", "Ramskapelle-Knokke-Heist", "Ramskapelle-Nieuwpoort",
        "Rance", "Ransart", "Ransberg", "Ranst", "Ravels", "Rebaix", "Rebecq",
        "Rebecq-Rognon", "Recht", "Recogne", "Redu", "Reet", "Rekem", "Rekkem", "Relegem",
        "Remagne", "Remersdaal", "Remicourt", "Rendeux", "Reninge", "Reningelst",
        "Renlies", "Reppel", "Ressaix", "Ressegem", "Resteigne", "Retie", "Retinne",
        "Reuland", "Rhisnes", "Richelle", "Riemst", "Rienne", "Rijkel", "Rijkevorsel",
        "Rijkhoven", "Rijmenam", "Riksingen", "Rillaar", "Rivière", "Rixensart", "Rièzes",
        "Robechies", "Robelmont", "Robertville", "Roborst", "Rochefort", "Rochehaut",
        "Rocherath", "Roclenge-sur-Geer", "Rocourt", "Roesbrugge-Haringe", "Roeselare",
        "Rognée", "Roisin", "Roksem", "Rollegem", "Rollegem-Kapelle", "Roloux", "Roly",
        "Romedenne", "Romershoven", "Romerée", "Romsée", "Rongy", "Ronquières", "Ronse",
        "Ronsele", "Roosbeek", "Roosdaal", "Roselies", "Rosières", "Rosmeer",
        "Rosoux-Crenwick", "Rossignol", "Rosée", "Rotem", "Rotheux-Rimière", "Rotselaar",
        "Roucourt", "Rouveroy", "Rouvreux", "Rouvroy", "Roux", "Roux-Miroir", "Roy",
        "Rozebeke", "Ruddervoorde", "Ruette", "Ruien", "Ruisbroek", "Ruiselede",
        "Rukkelingen-Loon", "Rulles", "Rumbeke", "Rumes", "Rumillies", "Rummen",
        "Rumsdorp", "Rumst", "Runkelen", "Rupelmonde", "Russeignies", "Rutten", "Rèves",
        "Saint-Amand", "Saint-André", "Saint-Aubin", "Saint-Denis", "Saint-Denis-Bovesse",
        "Saint-Georges-sur-Meuse", "Saint-Germain", "Saint-Ghislain", "Saint-Gérard",
        "Saint-Géry", "Saint-Hubert", "Saint-Jean-Geest", "Saint-Léger", "Saint-Marc",
        "Saint-Mard", "Saint-Martin", "Saint-Maur", "Saint-Médard", "Saint-Nicolas",
        "Saint-Pierre", "Saint-Remy", "Saint-Remy-Geest", "Saint-Sauveur",
        "Saint-Servais", "Saint-Symphorien", "Saint-Séverin", "Saint-Vaast",
        "Saint-Vincent", "Sainte-Cécile", "Sainte-Marie-Chevigny",
        "Sainte-Marie-sur-Semois", "Sainte-Ode", "Saintes", "Saive", "Salles", "Samart",
        "Sambreville", "Samrée", "Sankt-Vith", "Sars-la-Bruyère", "Sars-la-Buissière",
        "Sart-Bernard", "Sart-Custinne", "Sart-Dames-Avelines", "Sart-Eustache",
        "Sart-Saint-Laurent", "Sart-en-Fagne", "Sart-lez-Spa", "Sautin", "Sautour",
        "Sauvenière", "Schaarbeek", "Schaffen", "Schalkhoven", "Schaltin", "Schelderode",
        "Scheldewindeke", "Schelle", "Schellebelle", "Schendelbeke", "Schepdaal",
        "Scherpenheuvel", "Scherpenheuvel-Zichem", "Schilde", "Schoonaarde", "Schore",
        "Schorisse", "Schoten", "Schriek", "Schuiferskapelle", "Schulen", "Schönberg",
        "Sclayn", "Scy", "Seilles", "Seloignes", "Semmerzake", "Seneffe", "Sensenruth",
        "Seny", "Senzeille", "Septon", "Seraing", "Seraing-le-Château", "Serinchamps",
        "Serskamp", "Serville", "Sibret", "Signeulx", "Sijsele", "Silenrieux", "Silly",
        "Sinaai-Waas", "Sinsin", "Sint-Agatha-Berchem", "Sint-Agatha-Rode", "Sint-Amands",
        "Sint-Amandsberg", "Sint-Andries", "Sint-Antelinks", "Sint-Baafs-Vijve",
        "Sint-Blasius-Boekel", "Sint-Denijs", "Sint-Denijs-Boekel", "Sint-Denijs-Westrem",
        "Sint-Eloois-Vijve", "Sint-Eloois-Winkel", "Sint-Genesius-Rode", "Sint-Gillis",
        "Sint-Gillis-Waas", "Sint-Gillis-bij-Dendermonde", "Sint-Goriks-Oudenhove",
        "Sint-Huibrechts-Hern", "Sint-Huibrechts-Lille", "Sint-Jacobs-Kapelle",
        "Sint-Jan", "Sint-Jan-in-Eremo", "Sint-Jans-Molenbeek", "Sint-Job-in-'t-Goor",
        "Sint-Joost-ten-Node", "Sint-Joris-Beernem", "Sint-Joris-Nieuwpoort",
        "Sint-Joris-Weert", "Sint-Joris-Winge", "Sint-Katelijne-Waver",
        "Sint-Katherina-Lombeek", "Sint-Kornelis-Horebeke", "Sint-Kruis",
        "Sint-Kruis-Winkel", "Sint-Kwintens-Lennik", "Sint-Lambrechts-Herk",
        "Sint-Lambrechts-Woluwe", "Sint-Laureins", "Sint-Laureins-Berchem",
        "Sint-Lenaarts", "Sint-Lievens-Esse", "Sint-Lievens-Houtem", "Sint-Margriete",
        "Sint-Margriete-Houtem", "Sint-Maria-Horebeke", "Sint-Maria-Latem",
        "Sint-Maria-Lierde", "Sint-Maria-Oudenhove-Brakel",
        "Sint-Maria-Oudenhove-Zottegem", "Sint-Martens-Bodegem", "Sint-Martens-Latem",
        "Sint-Martens-Leerne", "Sint-Martens-Lennik", "Sint-Martens-Lierde",
        "Sint-Martens-Voeren", "Sint-Michiels", "Sint-Niklaas", "Sint-Pauwels",
        "Sint-Pieters-Kapelle", "Sint-Pieters-Leeuw", "Sint-Pieters-Rode",
        "Sint-Pieters-Voeren", "Sint-Pieters-Woluwe", "Sint-Rijkers",
        "Sint-Stevens-Woluwe", "Sint-Truiden", "Sint-Ulriks-Kapelle", "Sippenaeken",
        "Sirault", "Sivry", "Sivry-Rance", "Sleidinge", "Slijpe", "Slins", "Sluizen",
        "Smeerebbe-Vloerzegem", "Smetlede", "Smuid", "Snaaskerke", "Snellegem",
        "Soheit-Tinlot", "Sohier", "Soignies", "Soiron", "Solre-Saint-Géry",
        "Solre-sur-Sambre", "Sombreffe", "Somme-Leuze", "Sommethonne", "Sommière",
        "Somzée", "Sorinne-la-Longue", "Sorinnes", "Sorée", "Sosoye", "Sougné-Remouchamps",
        "Soulme", "Soumagne", "Soumoy", "Sourbrodt", "Souvret", "Sovet", "Soy", "Soye",
        "Spa", "Spalbeek", "Spermalie", "Spiennes", "Spiere", "Spiere-Helkijn", "Spontin",
        "Spouwen", "Sprimont", "Spy", "Stabroek", "Staden", "Stalhille", "Stambruges",
        "Stave", "Stavele", "Stavelot", "Steendorp", "Steenhuffel",
        "Steenhuize-Wijnhuize", "Steenkerke", "Steenkerque", "Steenokkerzeel", "Stekene",
        "Stembert", "Stene", "Sterrebeek", "Stevoort", "Stokrooie", "Stoumont",
        "Straimont", "Strijpen", "Strijtem", "Strombeek-Bever", "Strée", "Strée-lez-Huy",
        "Strépy-Bracquegnies", "Stuivekenskerke", "Suarlée", "Sugny", "Surice", "Suxy",
        "Sélange", "Tailles", "Taintignies", "Tamines", "Tarcienne", "Tavier", "Taviers",
        "Tavigny", "Tellin", "Templeuve", "Temploux", "Temse", "Tenneville", "Teralfene",
        "Terhagen", "Termes", "Ternat", "Tertre", "Tervuren", "Terwagne", "Tessenderlo",
        "Testelt", "Teuven", "Theux", "Thiaumont", "Thieu", "Thieulain", "Thieusies",
        "Thimister", "Thimister-Clermont", "Thimougies", "Thiméon", "Thines", "Thirimont",
        "Thisnes", "Thommen", "Thon", "Thorembais-Saint-Trond", "Thorembais-les-Béguines",
        "Thoricourt", "Thuillies", "Thuin", "Thulin", "Thumaide", "Thy-le-Bauduin",
        "Thy-le-Château", "Thynes", "Thys", "Tiegem", "Tielen", "Tielrode", "Tielt",
        "Tielt-Winge", "Tienen", "Tignée", "Tihange", "Tildonk", "Tilff", "Tillet",
        "Tilleur", "Tillier", "Tilly", "Tinlot", "Tintange", "Tintigny", "Tisselt",
        "Toernich", "Tohogne", "Tollembeek", "Tongeren", "Tongerlo", "Tongre-Notre-Dame",
        "Tongre-Saint-Martin", "Tongrinne", "Tontelange", "Torgny", "Torhout", "Tourinne",
        "Tourinnes-Saint-Lambert", "Tournai", "Tournay", "Tourpes", "Transinne",
        "Trazegnies", "Treignes", "Trembleur", "Tremelo", "Trivières", "Trognée",
        "Trois-Ponts", "Trooz", "Tubize", "Turnhout", "Ucimont", "Uikhoven", "Uitbergen",
        "Uitkerke", "Ukkel", "Ulbeek", "Upigny", "Ursel", "Vaalbeek", "Val-Meer", "Vance",
        "Varendonk", "Varsenare", "Vaucelles", "Vaulx", "Vaulx-lez-Chimay",
        "Vaux-Chavanne", "Vaux-et-Borset", "Vaux-lez-Rosières", "Vaux-sous-Chèvremont",
        "Vaux-sur-Sûre", "Vechmaal", "Vedrin", "Veerle", "Velaine-sur-Sambre", "Velaines",
        "Veldegem", "Veldwezelt", "Vellereille-le-Sec", "Vellereille-les-Brayeux", "Velm",
        "Velroux", "Veltem-Beisem", "Velzeke-Ruddershove", "Vencimont", "Vergnies",
        "Verlaine", "Verlée", "Verrebroek", "Vertrijk", "Verviers", "Vesqueville",
        "Veulen", "Veurne", "Vezin", "Vezon", "Viane", "Vichte", "Vielsalm", "Viemme",
        "Viersel", "Vierset-Barse", "Vierves-sur-Viroin", "Viesville", "Vieux-Genappe",
        "Vieux-Waleffe", "Vieuxville", "Villance", "Ville-Pommeroeul", "Ville-en-Hesbaye",
        "Ville-sur-Haine", "Villerot", "Villers-Deux-Eglises", "Villers-Notre-Dame",
        "Villers-Perwin", "Villers-Poterie", "Villers-Saint-Amand",
        "Villers-Saint-Ghislain", "Villers-Saint-Siméon", "Villers-Sainte-Gertrude",
        "Villers-aux-Tours", "Villers-devant-Orval", "Villers-en-Fagne",
        "Villers-l'Evêque", "Villers-la-Bonne-Eau", "Villers-la-Loue", "Villers-la-Tour",
        "Villers-la-Ville", "Villers-le-Bouillet", "Villers-le-Gambon",
        "Villers-le-Peuplier", "Villers-le-Temple", "Villers-lez-Heest",
        "Villers-sur-Lesse", "Villers-sur-Semois", "Vilvoorde", "Vinalmont",
        "Vinderhoute", "Vinkem", "Vinkt", "Virelles", "Virginal-Samme", "Viroinval",
        "Virton", "Vissenaken", "Visé", "Vitrival", "Vivegnis", "Vivy", "Vladslo",
        "Vlamertinge", "Vlekkem", "Vleteren", "Vlezenbeek", "Vliermaal", "Vliermaalroot",
        "Vlierzele", "Vlijtingen", "Vlimmeren", "Vlissegem", "Vloesberg", "Vodecée",
        "Vodelée", "Voeren", "Vogenée", "Volkegem", "Vollezele", "Vonêche", "Voorde",
        "Voormezele", "Voort", "Voroux-Goreux", "Voroux-lez-Liers", "Vorselaar", "Vorsen",
        "Vorst", "Vosselaar", "Vosselare", "Vossem", "Vottem", "Vrasene", "Vremde",
        "Vreren", "Vresse-sur-Semois", "Vroenhoven", "Vucht", "Vurste", "Vyle-et-Tharoul",
        "Waanrode", "Waarbeke", "Waardamme", "Waarloos", "Waarmaarde", "Waarschoot",
        "Waasmont", "Waasmunster", "Waasten", "Wachtebeke", "Wadelincourt", "Wagnelée",
        "Waha", "Waillet", "Wakken", "Walcourt", "Walem", "Walhain", "Walhain-Saint-Paul",
        "Walhorn", "Walsbets", "Walshoutem", "Waltwilder", "Wambeek", "Wancennes",
        "Wandre", "Wanfercée-Baulet", "Wange", "Wangenies", "Wanlin", "Wanne",
        "Wannebecq", "Wannegem-Lede", "Wansin", "Wanze", "Wanzele", "Warchin", "Warcoing",
        "Wardin", "Waregem", "Waremme", "Waret-l'Evêque", "Waret-la-Chaussée",
        "Warisoulx", "Warnant", "Warnant-Dreye", "Warquignies", "Warsage", "Warzée",
        "Wasmes", "Wasmes-Audemez-Briffoeil", "Wasmuel", "Wasseiges", "Waterland-Oudeman",
        "Waterloo", "Watermaal-Bosvoorde", "Watervliet", "Watou", "Wattripont", "Waudrez",
        "Waulsort", "Wauthier-Braine", "Waver", "Wavreille", "Wayaux", "Ways", "Webbekom",
        "Wechelderzande", "Weelde", "Weerde", "Weert", "Wegnez", "Weillen", "Weismes",
        "Welden", "Welkenraedt", "Welle", "Wellen", "Wellin", "Wemmel", "Wenduine",
        "Werbomont", "Werchter", "Werken", "Werm", "Wervik", "Wespelaar", "Westende",
        "Westerlo", "Westkapelle", "Westkerke", "Westmalle", "Westmeerbeek", "Westouter",
        "Westrem", "Westrozebeke", "Westvleteren", "Wetteren", "Wevelgem", "Wez-Velvain",
        "Wezemaal", "Wezembeek-Oppem", "Wezeren", "Wibrin", "Wichelen", "Widooie",
        "Wiekevorst", "Wielsbeke", "Wierde", "Wiers", "Wiesme", "Wieze", "Wihogne",
        "Wihéries", "Wijchmaal", "Wijer", "Wijgmaal", "Wijnegem", "Wijshagen",
        "Wijtschate", "Wilderen", "Willaupuis", "Willebringen", "Willebroek", "Willemeau",
        "Willerzie", "Wilrijk", "Wilsele", "Wilskerke", "Wimmertingen", "Winenne",
        "Wingene", "Winksele", "Wintershoven", "Witry", "Wodecq", "Woesten", "Wolkrange",
        "Wolvertem", "Wommelgem", "Wommersom", "Wonck", "Wondelgem", "Wontergem",
        "Wortegem", "Wortegem-Petegem", "Wortel", "Woubrechtegem", "Woumen", "Wulpen",
        "Wulvergem", "Wulveringem", "Wuustwezel", "Wépion", "Wéris", "Xhendelesse",
        "Xhendremael", "Xhoris", "Yernée-Fraineux", "Yves-Gomezée", "Yvoir", "Zaffelare",
        "Zandbergen", "Zande", "Zandhoven", "Zandvliet", "Zandvoorde-Oostende",
        "Zandvoorde-Zonnebeke", "Zarlardinge", "Zarren", "Zaventem", "Zedelgem",
        "Zeebrugge", "Zegelsem", "Zele", "Zelem", "Zellik", "Zelzate", "Zemst",
        "Zepperen", "Zerkegem", "Zevekote", "Zeveneken", "Zeveren", "Zevergem", "Zichem",
        "Zichen-Zussen-Bolder", "Zillebeke", "Zingem", "Zoerle-Parwijs", "Zoersel",
        "Zolder", "Zomergem", "Zonhoven", "Zonnebeke", "Zonnegem", "Zottegem",
        "Zoutenaaie", "Zoutleeuw", "Zuidschote", "Zuienkerke", "Zulte", "Zulzeke",
        "Zutendaal", "Zwalm", "Zwevegem", "Zwevezele", "Zwijnaarde", "Zwijndrecht",
        "Zétrud-Lumay", "l'Escaillère"
    )

    provinces = (
        "Antwerpen", "Henegouwen", "Limburg", "Luik", "Luxemburg", "Namen",
        "Oost-Vlaanderen", "Vlaams-Brabant", "Waals-Brabant", "West-Vlaanderen"
    )

    street_name_formats = (
        '{{first_name}}{{street_suffix}}',
    )

    street_address_formats = (
        '{{street_name}} {{building_number}}',
    )

    address_formats = (
        "{{street_address}}\n{{postcode}}\n{{city}}",
        "{{street_address}}\n{{postcode}} {{city}}",
    )

    def province(self):
        return self.random_element(self.provinces)

    def city(self):
        return self.random_element(self.cities)



# -*- coding: utf-8 -*-
from __future__ import unicode_literals

from .. import Provider as AddressProvider


class Provider(AddressProvider):
    address_formats = (
        '{{prefecture}}{{city}}{{town}}{{chome}}{{ban}}{{gou}}',
        '{{prefecture}}{{city}}{{town}}{{chome}}{{ban}}{{gou}} {{town}}{{building_name}}{{building_number}}',
        '{{prefecture}}{{city}}{{town}}{{chome}}{{ban}}{{gou}} {{building_name}}{{town}}{{building_number}}', )

    building_number_formats = ('###', )

    countries = (
        'アフガニスタン',
        'アルバニア',
        'アルジェリア',
        'アメリカ領サモア',
        'アンドラ',
        'アンゴラ',
        'アンギラ',
        '南極大陸',
        'アンティグアバーブーダ',
        'アルゼンチン',
        'アルメニア',
        'アルバ',
        'オーストラリア',
        'オーストリア',
        'アゼルバイジャン',
        'バハマ',
        'バーレーン',
        'バングラデシュ',
        'バルバドス',
        'ベラルーシ',
        'ベルギー',
        'ベリーズ',
        'ベナン',
        'バミューダ島',
        'ブータン',
        'ボリビア',
        'ボスニア・ヘルツェゴビナ',
        'ボツワナ',
        'ブーベ島',
        'ブラジル',
        'イギリス領インド洋地域',
        'イギリス領ヴァージン諸島',
        'ブルネイ',
        'ブルガリア',
        'ブルキナファソ',
        'ブルンジ',
        'カンボジア',
        'カメルーン',
        'カナダ',
        'カーボベルデ',
        'ケイマン諸島',
        '中央アフリカ共和国',
        'チャド',
        'チリ',
        '中国',
        'クリスマス島',
        'ココス諸島',
        'コロンビア',
        'コモロ',
        'コンゴ共和国',
        'クック諸島',
        'コスタリカ',
        'コートジボワール',
        'クロアチア',
        'キューバ',
        'キプロス共和国',
        'チェコ共和国',
        'デンマーク',
        'ジブチ共和国',
        'ドミニカ国',
        'ドミニカ共和国',
        'エクアドル',
        'エジプト',
        'エルサルバドル',
        '赤道ギニア共和国',
        'エリトリア',
        'エストニア',
        'エチオピア',
        'フェロー諸島',
        'フォークランド諸島',
        'フィジー共和国',
        'フィンランド',
        'フランス',
        'フランス領ギアナ',
        'フランス領ポリネシア',
        'フランス領極南諸島',
        'ガボン',
        'ガンビア',
        'グルジア',
        'ドイツ',
        'ガーナ',
        'ジブラルタル',
        'ギリシャ',
        'グリーンランド',
        'グレナダ',
        'グアドループ',
        'グアム',
        'グアテマラ',
        'ガーンジー',
        'ギニア',
        'ギニアビサウ',
        'ガイアナ',
        'ハイチ',
        'ハード島とマクドナルド諸島',
        'バチカン市国',
        'ホンジュラス',
        '香港',
        'ハンガリー',
        'アイスランド',
        'インド',
        'インドネシア',
        'イラン',
        'イラク',
        'アイルランド共和国',
        'マン島',
        'イスラエル',
        'イタリア',
        'ジャマイカ',
        '日本',
        'ジャージー島',
        'ヨルダン',
        'カザフスタン',
        'ケニア',
        'キリバス',
        '朝鮮',
        '韓国',
        'クウェート',
        'キルギス共和国',
        'ラオス人民民主共和国',
        'ラトビア',
        'レバノン',
        'レソト',
        'リベリア',
        'リビア国',
        'リヒテンシュタイン',
        'リトアニア',
        'ルクセンブルク',
        'マカオ',
        'マケドニア共和国',
        'マダガスカル',
        'マラウィ',
        'マレーシア',
        'モルディブ',
        'マリ',
        'マルタ共和国',
        'マーシャル諸島',
        'マルティニーク',
        'モーリタニア・イスラム共和国',
        'モーリシャス',
        'マヨット',
        'メキシコ',
        'ミクロネシア連邦',
        'モルドバ共和国',
        'モナコ公国',
        'モンゴル',
        'モンテネグロ共和国',
        'モントセラト',
        'モロッコ',
        'モザンビーク',
        'ミャンマー',
        'ナミビア',
        'ナウル',
        'ネパール',
        'オランダ領アンティル',
        'オランダ',
        'ニューカレドニア',
        'ニュージーランド',
        'ニカラグア',
        'ニジェール',
        'ナイジェリア',
        'ニース',
        'ノーフォーク島',
        '北マリアナ諸島',
        'ノルウェー',
        'オマーン',
        'パキスタン',
        'パラオ',
        'パレスチナ自治区',
        'パナマ',
        'パプアニューギニア',
        'パラグアイ',
        'ペルー',
        'フィリピン',
        'ピトケアン諸島',
        'ポーランド',
        'ポルトガル',
        'プエルトリコ',
        'カタール',
        'レユニオン',
        'ルーマニア',
        'ロシア',
        'ルワンダ',
        'サン・バルテルミー島',
        'セントヘレナ',
        'セントクリストファー・ネイビス連邦',
        'セントルシア',
        'セント・マーチン島',
        'サンピエール島・ミクロン島',
        'セントビンセント・グレナディーン',
        'サモア',
        'サンマリノ',
        'サントメプリンシペ',
        'サウジアラビア',
        'セネガル',
        'セルビア',
        'セイシェル',
        'シエラレオネ',
        'シンガポール',
        'スロバキア',
        'スロベニア',
        'ソロモン諸島',
        'ソマリア',
        '南アフリカ共和国',
        'サウスジョージア・サウスサンドウィッチ諸島',
        'スペイン',
        'スリランカ',
        'スーダン',
        'スリナム',
        'スヴァールバル諸島およびヤンマイエン島',
        'スワジランド王国',
        'スウェーデン',
        'スイス',
        'シリア',
        '台湾',
        'タジキスタン共和国',
        'タンザニア',
        'タイ',
        '東ティモール',
        'トーゴ',
        'トケラウ',
        'トンガ',
        'トリニダード・トバゴ',
        'チュニジア',
        'トルコ',
        'トルクメニスタン',
        'タークス・カイコス諸島',
        'ツバル',
        'ウガンダ',
        'ウクライナ',
        'アラブ首長国連邦',
        'イギリス',
        'アメリカ合衆国',
        '合衆国領有小離島',
        'アメリカ領ヴァージン諸島',
        'ウルグアイ',
        'ウズベキスタン',
        'バヌアツ',
        'ベネズエラ',
        'ベトナム',
        'ウォリス・フツナ',
        '西サハラ',
        'イエメン',
        'ザンビア',
        'ジンバブエ',
    )

    prefectures = (
        '北海道', '青森県', '岩手県', '宮城県', '秋田県', '山形県', '福島県', '茨城県', '栃木県', '群馬県',
        '埼玉県', '千葉県', '東京都', '神奈川県', '新潟県', '富山県', '石川県', '福井県', '山梨県', '長野県',
        '岐阜県', '静岡県', '愛知県', '三重県', '滋賀県', '京都府', '大阪府', '兵庫県', '奈良県', '和歌山県',
        '鳥取県', '島根県', '岡山県', '広島県', '山口県', '徳島県', '香川県', '愛媛県', '高知県', '福岡県',
        '佐賀県', '長崎県', '熊本県', '大分県', '宮崎県', '鹿児島県', '沖縄県'
    )

    cities = (
        '八千代市', '我孫子市', '鴨川市', '鎌ケ谷市', '君津市', '富津市', '浦安市', '四街道市', '袖ケ浦市',
        '八街市', '印西市', '白井市', '富里市', '南房総市', '匝瑳市', '香取市', '山武市', 'いすみ市', '大網白里市',
        '印旛郡酒々井町', '印旛郡印旛村', '印旛郡本埜村', '印旛郡栄町', '香取郡神崎町', '香取郡多古町', '香取郡東庄町',
        '山武郡九十九里町', '山武郡芝山町', '山武郡横芝光町', '長生郡一宮町', '長生郡睦沢町', '長生郡長生村',
        '長生郡白子町', '長生郡長柄町', '長生郡長南町', '夷隅郡大多喜町', '夷隅郡御宿町', '安房郡鋸南町', '千代田区',
        '中央区', '港区', '新宿区', '文京区', '台東区', '墨田区', '江東区', '品川区', '目黒区', '大田区',
        '世田谷区', '渋谷区', '中野区', '杉並区', '豊島区', '北区', '荒川区', '板橋区', '練馬区', '足立区',
        '葛飾区', '江戸川区', '八王子市', '立川市', '武蔵野市', '三鷹市', '青梅市', '府中市', '昭島市', '調布市',
        '町田市', '小金井市', '小平市', '日野市', '東村山市', '国分寺市', '国立市', '福生市', '狛江市', '東大和市',
        '清瀬市', '東久留米市', '武蔵村山市', '多摩市', '稲城市', '羽村市', 'あきる野市', '西東京市', '西多摩郡瑞穂町',
        '西多摩郡日の出町', '西多摩郡檜原村', '西多摩郡奥多摩町', '大島町', '利島村', '新島村', '神津島村', '三宅島三宅村',
        '御蔵島村', '八丈島八丈町', '青ヶ島村', '小笠原村', '横浜市鶴見区', '横浜市神奈川区', '横浜市西区', '横浜市中区',
        '横浜市南区', '横浜市保土ケ谷区', '横浜市磯子区', '横浜市金沢区', '横浜市港北区', '横浜市戸塚区', '横浜市港南区',
        '横浜市旭区', '横浜市緑区', '横浜市瀬谷区', '横浜市栄区', '横浜市泉区', '横浜市青葉区', '横浜市都筑区',
        '川崎市川崎区', '川崎市幸区', '川崎市中原区', '川崎市高津区', '川崎市多摩区', '川崎市宮前区'
    )

    towns = (
        '丹勢', '中宮祠', '手岡', '東和町', '所野', '土沢', '独鈷沢', '轟', '土呂部', '中小来川', '長畑', '中鉢石町',
        '中三依', '西小来川', '西川', '日光', '東三島', '東大和町', '蟇沼', '二つ室', '方京', '細竹', '前弥六',
        '前弥六南町', '松浦町', '南赤田', '南郷屋', '美原町', '無栗屋', '睦', '百村', '箭坪', '山中新田', '油井',
        '湯宮', '豊町', '湯本塩原', '横林', '四区町', '渡辺', '氏家', '氏家新田', '卯の里', '小入', '大中', '押上',
        '柿木沢', '柿木沢新田', '鍛冶ケ沢', '上高野', '上吉羽', '木立', '権現堂', '幸手', '下宇和田', '下吉羽', '神明内',
        '外国府間', '千塚', '天神島', '戸島', '中川崎', '長間', '西関宿', '花島', '平須賀', '細野', '松石', '太田ヶ谷',
        '上広谷', '五味ヶ谷', '脚折', '脚折町', '鶴ヶ丘', '羽折町', '藤金', '九段南', '皇居外苑', '麹町', '猿楽町',
        '外神田', '西神田', '隼町', '東神田', '一ツ橋', '日比谷公園', '平河町', '丸の内', '丸の内ＪＰタワー', '四番町',
        '六番町', '明石町', '勝どき', '京橋', '月島', '北青山', '港南', '芝浦', '芝公園', '芝大門', '白金', '白金台',
        '台場', '高輪', '虎ノ門', '虎ノ門虎ノ門ヒルズ森タワー', '大京町', '高田馬場', '箪笥町', '津久戸町', '筑土八幡町',
        '戸塚町', '富久町', '戸山', '秋葉原', '浅草', '浅草橋', '池之端', '今戸', '入谷', '上野公園', '上野桜木',
        '雷門', '北上野', '蔵前', '千束', '台東', '鳥越', '西浅草', '日本堤', '橋場', '花川戸', '東浅草', '東上野',
        '松が谷', '三筋', '三ノ輪', '元浅草', '竜泉', '吾妻橋'
    )

    building_names = (
        'パレス', 'ハイツ', 'コーポ', 'アーバン', 'クレスト', 'パーク', 'シティ', 'シャルム', 'コート',
    )

    def prefecture(self):
        """
        :example '東京都'
        """
        return self.random_element(self.prefectures)

    def city(self):
        """
        :example '台東区'
        """
        return self.random_element(self.cities)

    def town(self):
        """
        :example '浅草'
        """
        return self.random_element(self.towns)

    def chome(self):
        """
        :example '1丁目'
        """
        return "%d丁目" % self.generator.random.randint(1, 42)

    def ban(self):
        """
        :example '3番'
        """
        return "%d番" % self.generator.random.randint(1, 27)

    def gou(self):
        """
        :example '10号'
        """
        return "%d号" % self.generator.random.randint(1, 20)

    def building_name(self):
        """
        :example 'コーポ芝浦'
        """
        return self.random_element(self.building_names)

    def zipcode(self):
        """
        :example '101-1212'
        """
        return "%03d-%04d" % (self.generator.random.randint(0, 999),
                              self.generator.random.randint(0, 9999))



#  -*- coding: utf-8 -*-

from __future__ import unicode_literals
from .. import Provider as SsnProvider


def checksum(digits):
    s = 0
    p = len(digits) + 1
    for i in range(0, len(digits)):
        s += digits[i] * p
        p -= 1

    reminder = s % 11
    if reminder == 0 or reminder == 1:
        return 1
    else:
        return 11 - reminder


class Provider(SsnProvider):
    """
    Provider for Brazilian SSN also known in Brazil as CPF.
    There are two methods Provider.ssn and Provider.cpf
    The snn returns a valid number with numbers only
    The cpf return a valid number formatted with brazilian mask. eg nnn.nnn.nnn-nn
    """

    def ssn(self):
        digits = self.generator.random.sample(range(10), 9)

        dv = checksum(digits)
        digits.append(dv)
        digits.append(checksum(digits))

        return ''.join(map(str, digits))

    def cpf(self):
        c = self.ssn()
        return c[:3] + '.' + c[3:6] + '.' + c[6:9] + '-' + c[9:]



from __future__ import unicode_literals
from .. import Provider as PhoneNumberProvider


class Provider(PhoneNumberProvider):
    formats = (
        '+370 ########',
        '+(370) ########',
        '+370########'
    )



# coding=utf-8
from __future__ import unicode_literals
localized = True

from .. import BaseProvider


class Provider(BaseProvider):
    ssn_formats = ("###-##-####",)

    def ssn(self):
        return self.bothify(self.random_element(self.ssn_formats))



# coding=utf-8
from __future__ import unicode_literals
from .. import Provider as BaseProvider


class Provider(BaseProvider):
    # Source:
    # https://en.wikipedia.org/wiki/National_Insurance_number
    # UK National Insurance numbers (NINO) follow a specific format
    # To avoid generating real NINOs, the prefix and suffix letters
    # remain static using values reserved by HMRC (never to be used).
    # Example format: "QR 12 34 56 C" or "QR123456C" - only alphanumeric
    # and whitespace characters are permitted. Whitespace is for readability
    # only and is generally included as per the above examples, but a
    # few 'styles' have been included below for the sake of realism.

    nino_formats = (
        'ZZ ## ## ## T',
        'ZZ######T',
        'ZZ ###### T',
    )

    def ssn(self):
        pattern = self.random_element(self.nino_formats)
        return self.numerify(self.generator.parse(pattern))
